@@ -1,6 +1,7 @@
 import json
 import inspect
 import binascii
+import datetime
 
 import bizerror
 from fastutils.jsonutils import SimpleJsonEncoder
@@ -11,6 +12,7 @@ from django.db import models
 from django.core.serializers.json import DjangoJSONEncoder as DjangoJSONEncoderBase
 from django.forms.models import model_to_dict
 from django.core import serializers
+from django.utils import timezone
 
 def encode_model(o):
     text = serializers.serialize("json", [o])
@@ -29,8 +31,12 @@ def encode_queryset(q):
         data.append(obj)
     return data
 
+def encode_datetime(value):
+    return timezone.make_naive(value).strftime("%Y-%m-%d %H:%M:%S")
+
 SimpleJsonEncoder.library.register(models.Model, encode_model)
 SimpleJsonEncoder.library.register(models.QuerySet, encode_queryset)
+SimpleJsonEncoder.library.register(datetime.datetime, encode_datetime)
 
 def _get_request_data(request, extra_view_parameters):
     data = {"_request": request}
@@ -60,4 +66,3 @@ def _get_request_data(request, extra_view_parameters):
 
 def get_request_data(request, extra_view_parameters):
     return get_cached_value(request, "_django_apiview_request_data", _get_request_data, request, extra_view_parameters)
-
